import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Form, AddControlOptions, AddControlResponse, AddControlApplicationErrors, UpdateControlIdentifiers, UpdateControlOptions, UpdateControlResponse, UpdateControlApplicationErrors, DeleteControlIdentifiers, DeleteControlResponse, DeleteControlApplicationErrors, UpdateMessagesOptions, UpdateMessagesResponse, PublishDraftResponse, FormEventUpdatedEnvelope } from './index.typings.mjs';
export { ActionEvent, AddControlOptionsControlOneOf, AddControlRequest, AddControlRequestControlOneOf, AdditionalGuestsControl, Address, AddressControl, AddressControlLabels, AddressLocation, AddressStreetOneOf, Agenda, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, Badge, BaseEventMetadata, BlockquoteData, BookingData, Border, BorderColors, BulletedListData, ButtonData, ButtonDataType, CalendarLinks, CaptionData, Category, CategoryCounts, CellStyle, CheckboxControl, CheckoutFormMessages, CodeBlockData, CollapsibleListData, ColorData, Colors, ConferenceType, Crop, Dashboard, DateControl, Decoration, DecorationDataOneOf, DecorationType, DeleteControlRequest, Design, Dimensions, Direction, DiscardDraftRequest, DiscardDraftResponse, DividerData, DocumentStyle, DomainEvent, DomainEventBodyOneOf, DropdownControl, EmailControl, EmbedData, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, Event, EventData, EventDisplaySettings, EventStatus, EventType, EventUpdated, ExternalEvent, Feed, FileData, FileSource, FileSourceDataOneOf, FontSizeData, FontType, FormInputControlAdded, FormInputControlDeleted, FormInputControlUpdated, FormMessages, GIF, GIFData, GIFType, GalleryData, GalleryOptions, GetFormRequest, GetFormResponse, Gradient, GuestListConfig, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, InitialExpandedItems, Input, InputControl, InputControlType, Item, ItemDataOneOf, ItemStyle, Keyword, Label, LabellingSettings, Labels, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, LinkPreviewDataStyles, ListValue, Location, LocationType, MapCoordinates, MapData, MapSettings, MapType, Media, MentionData, MessageEnvelope, Metadata, Money, NameControl, NameControlLabels, Negative, NegativeResponseConfirmation, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Occurrence, Oembed, OnlineConferencing, OnlineConferencingConfig, OnlineConferencingSession, Option, OptionDesign, OptionLayout, OptionSelection, OptionSelectionSelectedOptionOneOf, OrderedListData, Orientation, PDFSettings, ParagraphData, Permissions, PhoneControl, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, PollSettings, Position, Positive, PositiveResponseConfirmation, PublishDraftRequest, RadioButtonControl, Recurrences, Registration, RegistrationClosedMessages, RegistrationStatus, Rel, RequestedFields, ResponseConfirmation, RestoreInfo, RichContent, RsvpCollection, RsvpCollectionConfig, RsvpFormMessages, RsvpStatusOptions, RsvpSummary, ScheduleConfig, Scheduling, SeoSchema, SeoSettings, Settings, SiteUrl, Source, Spoiler, SpoilerData, State, Status, StreetAddress, Styles, StylesBorder, Subdivision, SubdivisionType, TableCellData, TableData, Tag, Target, TaxConfig, TaxType, TextAlignment, TextControl, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, Ticketing, TicketingConfig, TicketingSummary, TicketsUnavailableMessages, Type, UpdateControlIdentifiersControlOneOf, UpdateControlOptionsControlOneOf, UpdateControlRequest, UpdateControlRequestControlOneOf, UpdateMessagesRequest, ValueType, VerticalAlignment, Video, VideoData, ViewMode, ViewRole, VisitorType, VoteRole, WebhookIdentityType, Width, WidthType } from './index.typings.mjs';

declare function getForm$1(httpClient: HttpClient): GetFormSignature;
interface GetFormSignature {
    /**
     * Retrieves an event registration form.
     *
     * Retrieves both the draft and published versions.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     * @returns Currently published event form.
     * Published form is visible to site visitors.
     */
    (eventId: string): Promise<Form>;
}
declare function addControl$1(httpClient: HttpClient): AddControlSignature;
interface AddControlSignature {
    /**
     * Adds an input control to the draft form.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     */
    (eventId: string, options: AddControlOptions): Promise<AddControlResponse & {
        __applicationErrorsType?: AddControlApplicationErrors | undefined;
    }>;
}
declare function updateControl$1(httpClient: HttpClient): UpdateControlSignature;
interface UpdateControlSignature {
    /**
     * Updates an existing input control in the draft form.
     * @param - Optional fields.
     * @param - Identifies what form to update.
     */
    (identifiers: UpdateControlIdentifiers, options?: UpdateControlOptions | undefined): Promise<UpdateControlResponse & {
        __applicationErrorsType?: UpdateControlApplicationErrors | undefined;
    }>;
}
declare function deleteControl$1(httpClient: HttpClient): DeleteControlSignature;
interface DeleteControlSignature {
    /**
     * Deletes an input control from the draft form.
     * @param - Identifies what form to delete.
     */
    (identifiers: DeleteControlIdentifiers): Promise<DeleteControlResponse & {
        __applicationErrorsType?: DeleteControlApplicationErrors | undefined;
    }>;
}
declare function updateMessages$1(httpClient: HttpClient): UpdateMessagesSignature;
interface UpdateMessagesSignature {
    /**
     * Updates a set of defined form messages that are displayed to a site visitor before, during, and after the registration flow.
     * Includes the configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     */
    (eventId: string, options?: UpdateMessagesOptions | undefined): Promise<UpdateMessagesResponse>;
}
declare function publishDraft$1(httpClient: HttpClient): PublishDraftSignature;
interface PublishDraftSignature {
    /**
     * Publishes the draft form.
     * @param - Event ID to which the form belongs.
     */
    (eventId: string): Promise<PublishDraftResponse>;
}
declare function discardDraft$1(httpClient: HttpClient): DiscardDraftSignature;
interface DiscardDraftSignature {
    /**
     * Clears all changes to the draft form.
     * @param - Event ID to which the form belongs.
     */
    (eventId: string): Promise<void>;
}
declare const onFormEventUpdated$1: EventDefinition<FormEventUpdatedEnvelope, "wix.events.events.EventUpdated">;

declare const getForm: MaybeContext<BuildRESTFunction<typeof getForm$1> & typeof getForm$1>;
declare const addControl: MaybeContext<BuildRESTFunction<typeof addControl$1> & typeof addControl$1>;
declare const updateControl: MaybeContext<BuildRESTFunction<typeof updateControl$1> & typeof updateControl$1>;
declare const deleteControl: MaybeContext<BuildRESTFunction<typeof deleteControl$1> & typeof deleteControl$1>;
declare const updateMessages: MaybeContext<BuildRESTFunction<typeof updateMessages$1> & typeof updateMessages$1>;
declare const publishDraft: MaybeContext<BuildRESTFunction<typeof publishDraft$1> & typeof publishDraft$1>;
declare const discardDraft: MaybeContext<BuildRESTFunction<typeof discardDraft$1> & typeof discardDraft$1>;
/**
 * Triggered when a form is updated or published.
 */
declare const onFormEventUpdated: BuildEventDefinition<typeof onFormEventUpdated$1>;

export { AddControlOptions, AddControlResponse, DeleteControlIdentifiers, DeleteControlResponse, Form, FormEventUpdatedEnvelope, PublishDraftResponse, UpdateControlIdentifiers, UpdateControlOptions, UpdateControlResponse, UpdateMessagesOptions, UpdateMessagesResponse, addControl, deleteControl, discardDraft, getForm, onFormEventUpdated, publishDraft, updateControl, updateMessages };
